import { useEffect } from "react"
import { motion, stagger, useAnimate } from "framer-motion"

export const WordEffect = ({
    words,
    filter = true,
    duration = 0.5,
    delay = 0.1,
    color = "black",
}) => {
    const [scope, animate] = useAnimate()
    const wordsArray = words.split(" ")
    useEffect(() => {
        animate(
            "span",
            {
                opacity: 1,
                filter: filter ? "blur(0px)" : "none",
            },
            {
                duration: duration ?? 1,
                delay: stagger(delay ?? 0.1),
            },
        )
    }, [scope.current])

    const renderWords = () => {
        return (
            <motion.div ref={scope}>
                {wordsArray.map((word, idx) => {
                    return (
                        <motion.span
                            key={word + idx}
                            style={{
                                opacity: 0,
                                filter: filter ? "blur(10px)" : "none",
                                color: color,
                                fontWeight: 'bold',
                                display: 'inline-block',
                            }}
                        >
                            {word}&nbsp;
                        </motion.span>
                    )
                })}
            </motion.div>
        )
    }

    return (
        <div
            style={{
                fontWeight: 'bold',
            }}
        >
            <div style={{ marginTop: '1rem' }}>
                <div
                    style={{
                        color: 'black',
                        fontSize: '1.5rem',
                        lineHeight: '2rem',
                        letterSpacing: '0.05em',
                    }}
                >
                    {renderWords()}
                </div>
            </div>
        </div >
    )
}

